==> zio-aws-dataexchange_2.13-5.17.129.2-sources.jar: zio/aws/dataexchange/model/package.scala <==
package zio.aws.dataexchange
import zio.aws.dataexchange.model.primitives.__string
import zio.prelude.Subtype
import java.time.Instant
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object ApiDescription extends Subtype[String]
    type ApiDescription =
      zio.aws.dataexchange.model.primitives.ApiDescription.Type
    object Arn extends Subtype[String]
    type Arn = zio.aws.dataexchange.model.primitives.Arn.Type
    object AssetName extends Subtype[String]
    type AssetName = zio.aws.dataexchange.model.primitives.AssetName.Type
    object Description extends Subtype[String]
    type Description = zio.aws.dataexchange.model.primitives.Description.Type
    object Id extends Subtype[String]
    type Id = zio.aws.dataexchange.model.primitives.Id.Type
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.dataexchange.model.primitives.MaxResults.Type
    object Name extends Subtype[String]
    type Name = zio.aws.dataexchange.model.primitives.Name.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.dataexchange.model.primitives.NextToken.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.dataexchange.model.primitives.Timestamp.Type
    object __boolean extends Subtype[Boolean]
    type __boolean = zio.aws.dataexchange.model.primitives.__boolean.Type
    object __double extends Subtype[Double]
    type __double = zio.aws.dataexchange.model.primitives.__double.Type
    object __doubleMin0 extends Subtype[Double]
    type __doubleMin0 = zio.aws.dataexchange.model.primitives.__doubleMin0.Type
    object __string extends Subtype[String]
    type __string = zio.aws.dataexchange.model.primitives.__string.Type
    object __stringMin0Max16384 extends Subtype[String]
    type __stringMin0Max16384 =
      zio.aws.dataexchange.model.primitives.__stringMin0Max16384.Type
    object __stringMin24Max24PatternAZaZ094AZaZ092AZaZ093
        extends Subtype[String]
    type __stringMin24Max24PatternAZaZ094AZaZ092AZaZ093 =
      zio.aws.dataexchange.model.primitives.__stringMin24Max24PatternAZaZ094AZaZ092AZaZ093.Type
  }
  type ListOfAssetDestinationEntry =
    List[zio.aws.dataexchange.model.AssetDestinationEntry]
  type ListOfAssetEntry = List[zio.aws.dataexchange.model.AssetEntry]
  type ListOfAssetSourceEntry =
    List[zio.aws.dataexchange.model.AssetSourceEntry]
  type ListOfDataSetEntry = List[zio.aws.dataexchange.model.DataSetEntry]
  type ListOfEventActionEntry =
    List[zio.aws.dataexchange.model.EventActionEntry]
  type ListOfJobEntry = List[zio.aws.dataexchange.model.JobEntry]
  type ListOfJobError = List[zio.aws.dataexchange.model.JobError]
  type ListOfRedshiftDataShareAssetSourceEntry =
    List[zio.aws.dataexchange.model.RedshiftDataShareAssetSourceEntry]
  type ListOfRevisionDestinationEntry =
    List[zio.aws.dataexchange.model.RevisionDestinationEntry]
  type ListOfRevisionEntry = List[zio.aws.dataexchange.model.RevisionEntry]
  type ListOf__string = List[__string]
  type MapOf__string = Map[__string, __string]
}

==> zio-aws-dataexchange_2.13-5.17.130.7-sources.jar: zio/aws/dataexchange/model/package.scala <==
package zio.aws.dataexchange
import zio.aws.dataexchange.model.primitives.__string
import zio.prelude.Subtype
import java.time.Instant
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object ApiDescription extends Subtype[String]
    type ApiDescription =
      zio.aws.dataexchange.model.primitives.ApiDescription.Type
    object Arn extends Subtype[String]
    type Arn = zio.aws.dataexchange.model.primitives.Arn.Type
    object AssetName extends Subtype[String]
    type AssetName = zio.aws.dataexchange.model.primitives.AssetName.Type
    object Description extends Subtype[String]
    type Description = zio.aws.dataexchange.model.primitives.Description.Type
    object Id extends Subtype[String]
    type Id = zio.aws.dataexchange.model.primitives.Id.Type
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.dataexchange.model.primitives.MaxResults.Type
    object Name extends Subtype[String]
    type Name = zio.aws.dataexchange.model.primitives.Name.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.dataexchange.model.primitives.NextToken.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.dataexchange.model.primitives.Timestamp.Type
    type __boolean = Boolean
    type __double = Double
    type __doubleMin0 = Double
    type __string = String
    type __stringMin0Max16384 = String
    type __stringMin24Max24PatternAZaZ094AZaZ092AZaZ093 = String
  }
  type ListOfAssetDestinationEntry =
    List[zio.aws.dataexchange.model.AssetDestinationEntry]
  type ListOfAssetEntry = List[zio.aws.dataexchange.model.AssetEntry]
  type ListOfAssetSourceEntry =
    List[zio.aws.dataexchange.model.AssetSourceEntry]
  type ListOfDataSetEntry = List[zio.aws.dataexchange.model.DataSetEntry]
  type ListOfEventActionEntry =
    List[zio.aws.dataexchange.model.EventActionEntry]
  type ListOfJobEntry = List[zio.aws.dataexchange.model.JobEntry]
  type ListOfJobError = List[zio.aws.dataexchange.model.JobError]
  type ListOfRedshiftDataShareAssetSourceEntry =
    List[zio.aws.dataexchange.model.RedshiftDataShareAssetSourceEntry]
  type ListOfRevisionDestinationEntry =
    List[zio.aws.dataexchange.model.RevisionDestinationEntry]
  type ListOfRevisionEntry = List[zio.aws.dataexchange.model.RevisionEntry]
  type ListOf__string = List[__string]
  type MapOf__string = Map[__string, __string]
}
